# coding=utf-8
import unittest
import py_pkg_demo


class TestDemo(unittest.TestCase):

    def test_failure(self):
        self.assertTrue(False)
